@@ -31,7 +31,7 @@ def service_client(url, timeout=(5, 5), http_adapter=None, before_request=None,
     return wrapper
 
 
-def service_mapping(uri, method, timeout=None, request_by_alias: bool = True):
+def service_mapping(uri, method, timeout=None, request_by_alias: bool = True, body_key='data'):
     def wrapper(f):
         full_arg_spec = inspect.getfullargspec(f)
         is_method = full_arg_spec.args and full_arg_spec.args[0] == 'self'
@@ -45,14 +45,9 @@ def service_mapping(uri, method, timeout=None, request_by_alias: bool = True):
             request_named_args = {k: v for k, v in named_args.items() if k not in has_format_names}
             data = None
             if method == HTTP_METHOD_POST or method == HTTP_METHOD_PUT:
-                if 'data' in request_named_args:
-                    data = request_named_args.get('data')
-                    request_named_args.pop('data')
-                if not data and len(full_arg_spec.args) > 1:
-                    first_arg = full_arg_spec.args[1]
-                    data = request_named_args.get(first_arg)
-                    request_named_args.pop(first_arg)
-
+                if body_key in request_named_args:
+                    data = request_named_args.get(body_key)
+                    request_named_args.pop(body_key)
             return request_named_args, data
 
         @wraps(f)
